El Androide Libre - Android: aplicaciones, juegos, noticias, smartphones. El Blog / Web de los androides

Liberar Android Imprescindibles Accesorios Programación Redeslibre Para Principiantes Otros android Contacta con EAL
http://www.omicrono.com
http://www.moosic.es
http://www.fandroides.com
http://www.elandroidelibre.com
http://www.cocinillas.es
http://www.medciencia.com
Seguir a @elandroidelibre
Android Studio 1.0 ya disponible, la primera versión estable
Los mejores móviles Android por menos de 300€
Android 5.0.1 Lollipop: Toda la información
Regalar apps: La opción que falta en Google Play
7
comentarios

Llega la navidad y toca gastarse un dineral en regalos a tocho y mocho. Y lo que es peor: ir a la tienda, avanzar a base de codazos y empujones entre los pasillos del centro comercial y criar setas en la barba mientras haces cola para pagar. Un festival, vamos. Durante mucho tiempo, las películas, libros y discos han sido uno de los regalos más recurrentes, el típico que nunca falla. Sin embargo en los últimos años la forma de consumir estos productos ha cambiado dramáticamente, del formato físico al digital. Las apps para teléfonos móviles...

Twittear
Leer más
Heroes of Might and Magic III para tablets Android con gráficos HD en 2015
1
Rotation Orientation Manager, controla al detalle la orientación de pantalla de tu Android
2
Así se distribuyen los beneficios de Google Play
8
Tutorial: Desactiva la reproducción automática de vídeos en Facebook
5
Descarga las APKs de Google Play desde tu PC con Raccoon
13
UBER prohibido en España
106
HTC Desire 620
8
El alto precio de la innovación
18
El 40% de los móviles proceden de China
7

El mercado chino ha vuelto a hacerlo: de jugador de segunda fila a potencia mundial en el ecosistema Android, gracias al 38.6 de envíos mundiales que...

Blackphone trabaja en su propia tienda de aplicaciones seguras y privadas
0

Tras lanzar el primer teléfono centrado en proteger la privacidad del usuario, Blackphone ha anunciado que lanzará, a partir de enero, su propia tienda...

Star Walk, la app más completa para el astrónomo aficionado
2

La astronomía es un mundo que, personalmente, me apasiona: la idea de tener tantos astros y cuerpos más allá de la frontera que marca la atmósfera...

Google Nexus 6 estuvo a punto de incluir lector de huellas dactilar
9

El código de Android 5.0 Lollipop confirma el soporte para lectores de huellas dactilares. También se desvela que Google estuvo a punto de incluir...

1. 1
2. 2
3. 3
4. 4
5. 5
6. 6
7. 7

Las cookies son necesarias para el funcionamiento del sitio. Al acceder a El Androide Libre, acepta el uso de ellas. Aceptar Más información